@@ -3,4 +3,5 @@ LSST JupyterLab Utilities
 """
 from jupyterlabutils.notebook import show_with_bokeh_server
 from ._version import __version__
-all = [show_with_bokeh_server]
+
+all = [show_with_bokeh_server, __version__]
